@@ -33,11 +33,11 @@ describe 'tripleo::profile::base::nova::compute::ironic' do
     context 'with step 4' do
       let(:pre_condition) do
         <<-eos
-        class { '::tripleo::profile::base::nova':
+        class { 'tripleo::profile::base::nova':
           step => #{params[:step]},
           oslomsg_rpc_hosts => [ '127.0.0.1' ],
         }
-        class { '::tripleo::profile::base::nova::compute':
+        class { 'tripleo::profile::base::nova::compute':
           step => #{params[:step]},
         }
 eos
