@@ -24,7 +24,7 @@ describe 'tripleo::profile::base::nova::compute::libvirt' do
 
       let(:pre_condition) do
         <<-eos
-        class { '::tripleo::profile::base::nova::compute_libvirt_shared':
+        class { 'tripleo::profile::base::nova::compute_libvirt_shared':
           step => #{params[:step]},
         }
 eos
@@ -43,20 +43,20 @@ eos
     context 'with step 4' do
       let(:pre_condition) do
         <<-eos
-        class { '::tripleo::profile::base::nova':
+        class { 'tripleo::profile::base::nova':
           step => #{params[:step]},
           oslomsg_rpc_hosts => [ '127.0.0.1' ],
         }
-        class { '::tripleo::profile::base::nova::compute_libvirt_shared':
+        class { 'tripleo::profile::base::nova::compute_libvirt_shared':
           step => #{params[:step]},
         }
-        class { '::tripleo::profile::base::nova::compute':
+        class { 'tripleo::profile::base::nova::compute':
           step => #{params[:step]},
         }
-        class { '::tripleo::profile::base::nova::migration':
+        class { 'tripleo::profile::base::nova::migration':
           step => #{params[:step]}
         }
-        class { '::tripleo::profile::base::nova::migration::client':
+        class { 'tripleo::profile::base::nova::migration::client':
           step => #{params[:step]}
         }
 eos
